report

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package report provides reporting functionality, including a TUI and text reports.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateTextReport

func GenerateTextReport(eng *engine.Engine, start time.Time) string

GenerateTextReport creates the final summary string.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model represents the state of the TUI.

func NewModel

func NewModel(eng *engine.Engine, duration time.Duration) Model

NewModel creates a new TUI model.

func (Model) FinalReport

func (m Model) FinalReport() string

FinalReport returns the final summary report as a string.

func (Model) Init

func (m Model) Init() tea.Cmd

Init initializes the TUI.

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update handles UI messages and updates the state.

func (Model) View

func (m Model) View() string

View renders the UI.

type TickMsg

type TickMsg time.Time

TickMsg is a message sent on each tick to update the UI.

Jump to